import { useMemo } from 'react';
import { useDispatch } from 'react-redux';
import { firstOfType } from '@resolve-js/core';
import { useCommandBuilder } from '@resolve-js/react-hooks';
import { isDependencies, isOptions } from '../helpers';
import { sendCommandFailure, sendCommandRequest, sendCommandSuccess } from './actions';
var internalActions = {
  request: function request(command) {
    return sendCommandRequest(command, true);
  },
  success: sendCommandSuccess,
  failure: sendCommandFailure
};
var defaultCommandOptions = {};
var defaultHookOptions = {};

function isBuilder(query) {
  return typeof query === 'function';
}

function useReduxCommand(command, options, dependencies) {
  var actualOptions = isOptions(options) ? options : defaultHookOptions;
  var actualActionCreators = actualOptions.actions || internalActions;
  var actualDependencies = firstOfType(isDependencies, options, dependencies);
  var request = actualActionCreators.request,
      success = actualActionCreators.success,
      failure = actualActionCreators.failure;

  var callback = function callback(error, result, executedCommand) {
    if (error || result == null) {
      if (typeof failure === 'function') {
        if (error) {
          dispatch(failure(executedCommand, error));
        } else {
          dispatch(failure(executedCommand, new Error("null response")));
        }
      }
    } else {
      if (typeof success === 'function') {
        dispatch(success(executedCommand, result));
      }
    }
  };

  var dispatch = useDispatch();
  var executor = actualDependencies ? useCommandBuilder(function (command) {
    return command;
  }, actualOptions.commandOptions || defaultCommandOptions, callback, actualDependencies) : useCommandBuilder(function (command) {
    return command;
  }, actualOptions.commandOptions || defaultCommandOptions, callback);
  return useMemo(function () {
    return {
      execute: function execute() {
        var dispatchRequest = function dispatchRequest(command) {
          if (typeof request === 'function') {
            dispatch(request(command));
          }
        };

        var plainCommand = isBuilder(command) ? command.apply(void 0, arguments) : command;
        dispatchRequest(plainCommand);
        executor(plainCommand);
      }
    };
  }, [executor, dispatch]);
}

export { useReduxCommand };
//# sourceMappingURL=use-redux-command.js.map