import _extends from "@babel/runtime/helpers/esm/extends";
import { createStore as reduxCreateStore, applyMiddleware, combineReducers, compose } from 'redux';
import { v4 as uuid } from 'uuid';
import { reducer as viewModelReducer } from './view-model/view-model-reducer';
import { reducer as readModelReducer } from './read-model/read-model-reducer';
import createResolveMiddleware from './create-resolve-middleware';
import deserializeInitialState from './internal/deserialize-initial-state';

var createStore = function createStore(_ref) {
  var _ref$redux = _ref.redux;
  _ref$redux = _ref$redux === void 0 ? {} : _ref$redux;
  var _ref$redux$reducers = _ref$redux.reducers,
      reducers = _ref$redux$reducers === void 0 ? {} : _ref$redux$reducers,
      _ref$redux$middleware = _ref$redux.middlewares,
      middlewares = _ref$redux$middleware === void 0 ? [] : _ref$redux$middleware,
      _ref$redux$enhancers = _ref$redux.enhancers,
      enhancers = _ref$redux$enhancers === void 0 ? [] : _ref$redux$enhancers,
      _ref$redux$sagas = _ref$redux.sagas,
      customSagas = _ref$redux$sagas === void 0 ? [] : _ref$redux$sagas,
      _ref$viewModels = _ref.viewModels,
      viewModels = _ref$viewModels === void 0 ? [] : _ref$viewModels,
      _ref$jwtProvider = _ref.jwtProvider,
      jwtProvider = _ref$jwtProvider === void 0 ? undefined : _ref$jwtProvider,
      origin = _ref.origin,
      rootPath = _ref.rootPath,
      staticPath = _ref.staticPath,
      _ref$initialState = _ref.initialState,
      initialState = _ref$initialState === void 0 ? undefined : _ref$initialState,
      serializedState = _ref.serializedState,
      isClient = _ref.isClient;
  // eslint-disable-next-line no-console
  console.warn('createStore function is deprecated and will be removed in future versions, migrate to createResolveStore');
  var sessionId = uuid();

  if (serializedState != null && initialState != null) {
    throw Error("ambiguous initial state: both initialState and serializedState set");
  }

  var actualInitialState;

  if (serializedState != null) {
    actualInitialState = deserializeInitialState(viewModels, serializedState);
  } else {
    actualInitialState = initialState;
  }

  var resolveMiddleware = createResolveMiddleware();
  var combinedReducers = combineReducers(_extends({}, reducers, {
    viewModels: viewModelReducer,
    readModels: readModelReducer,
    jwt: function jwt(_jwt) {
      if (_jwt === void 0) {
        _jwt = {};
      }

      return _jwt;
    }
  }));
  var appliedMiddlewares = applyMiddleware.apply(void 0, [resolveMiddleware].concat(middlewares));
  var composedEnhancers = compose.apply(void 0, [appliedMiddlewares].concat(enhancers));
  var store = reduxCreateStore(combinedReducers, actualInitialState, composedEnhancers);
  resolveMiddleware.run(isClient, {
    store: store,
    resolveContext: {
      viewModels: viewModels,
      rootPath: rootPath,
      staticPath: staticPath,
      origin: origin,
      jwtProvider: jwtProvider
    },
    customSagas: customSagas,
    sessionId: sessionId
  });
  return store;
};

export default createStore;
//# sourceMappingURL=create-store.js.map