import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React from 'react';
import { v4 as uuid } from 'uuid';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import hoistNonReactStatic from 'hoist-non-react-statics';
import * as actions from './actions';
import getHash from '../internal/get-hash';
import connectResolveAdvanced from '../internal/connect-resolve-advanced';
import { getEntry } from './view-model-reducer';
import { ResultStatus } from '../types';
export var mapDispatchToConnectorProps = function mapDispatchToConnectorProps(dispatch) {
  return bindActionCreators({
    connectViewModel: actions.connectViewModel,
    disconnectViewModel: actions.disconnectViewModel
  }, dispatch);
};
export var mapStateToConnectorProps = function mapStateToConnectorProps(mapStateToOptions, state, ownProps) {
  var connectorOptions = mapStateToOptions(state, ownProps);
  var entry = getEntry(state.viewModels, {
    query: {
      name: connectorOptions.viewModelName,
      aggregateIds: connectorOptions.aggregateIds,
      args: connectorOptions.aggregateArgs
    }
  });
  var data = entry && entry.status === ResultStatus.Ready ? entry.data : null;
  var error = entry && entry.status === ResultStatus.Failed ? entry.error : null;
  return {
    ownProps: ownProps,
    connectorOptions: connectorOptions,
    isLoading: entry && entry.status === ResultStatus.Requested,
    isFailure: entry && entry.status === ResultStatus.Failed,
    data: data,
    error: error
  };
};

var connectViewModel = function connectViewModel(mapStateToOptions) {
  return function (Component) {
    var selectorId = uuid();

    var ViewModelContainer = /*#__PURE__*/function (_React$PureComponent) {
      _inheritsLoose(ViewModelContainer, _React$PureComponent);

      function ViewModelContainer() {
        return _React$PureComponent.apply(this, arguments) || this;
      }

      var _proto = ViewModelContainer.prototype;

      _proto.componentDidMount = function componentDidMount() {
        var _this$props$connector = this.props.connectorOptions,
            viewModelName = _this$props$connector.viewModelName,
            aggregateIds = _this$props$connector.aggregateIds,
            aggregateArgs = _this$props$connector.aggregateArgs;
        this.props.connectViewModel({
          name: viewModelName,
          aggregateIds: aggregateIds,
          args: aggregateArgs
        }, selectorId);
      };

      _proto.componentWillUnmount = function componentWillUnmount() {
        var _this$props$connector2 = this.props.connectorOptions,
            viewModelName = _this$props$connector2.viewModelName,
            aggregateIds = _this$props$connector2.aggregateIds,
            aggregateArgs = _this$props$connector2.aggregateArgs;
        this.props.disconnectViewModel({
          name: viewModelName,
          aggregateIds: aggregateIds,
          args: aggregateArgs
        }, selectorId);
      };

      _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
        var connectorOptions = this.props.connectorOptions;
        var prevConnectorOptions = prevProps.connectorOptions;

        if (connectorOptions && prevConnectorOptions && (prevConnectorOptions.viewModelName !== connectorOptions.viewModelName || prevConnectorOptions.aggregateIds !== connectorOptions.aggregateIds || prevConnectorOptions.aggregateArgs !== connectorOptions.aggregateArgs) && (prevConnectorOptions.viewModelName !== connectorOptions.viewModelName || getHash(prevConnectorOptions.aggregateIds) !== getHash(connectorOptions.aggregateIds) || getHash(prevConnectorOptions.aggregateArgs, 'empty') !== getHash(connectorOptions.aggregateArgs, 'empty'))) {
          this.props.disconnectViewModel(prevConnectorOptions.viewModelName, prevConnectorOptions.aggregateIds, prevConnectorOptions.aggregateArgs);
          this.props.connectViewModel(connectorOptions.viewModelName, connectorOptions.aggregateIds, connectorOptions.aggregateArgs);
        }
      };

      _proto.render = function render() {
        var _this$props = this.props,
            ownProps = _this$props.ownProps,
            isLoading = _this$props.isLoading,
            data = _this$props.data;
        return /*#__PURE__*/React.createElement(Component, _extends({}, ownProps, {
          isLoading: isLoading,
          data: data
        }));
      };

      return ViewModelContainer;
    }(React.PureComponent);

    var ViewModelConnector = connect(mapStateToConnectorProps.bind(null, mapStateToOptions), mapDispatchToConnectorProps)(ViewModelContainer);
    ViewModelConnector.mapStateToOptions = mapStateToOptions;
    hoistNonReactStatic(ViewModelConnector, ViewModelContainer);
    return connectResolveAdvanced(ViewModelConnector);
  };
};

export default connectViewModel;
//# sourceMappingURL=connect-view-model.js.map