"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.createResolveStore = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _redux = require("redux");

var _uuid = require("uuid");

var _viewModelReducer = require("./view-model/view-model-reducer");

var _readModelReducer = require("./read-model/read-model-reducer");

var _createResolveMiddleware = _interopRequireDefault(require("./create-resolve-middleware"));

var _deserializeInitialState = _interopRequireDefault(require("./internal/deserialize-initial-state"));

var createResolveStore = function createResolveStore(resolveContext, params, isClient) {
  if (params === void 0) {
    params = {};
  }

  if (isClient === void 0) {
    isClient = true;
  }

  var sessionId = (0, _uuid.v4)();
  var viewModels = resolveContext.viewModels;
  var _params = params,
      initialState = _params.initialState,
      serializedState = _params.serializedState,
      _params$redux = _params.redux;
  _params$redux = _params$redux === void 0 ? {} : _params$redux;
  var _params$redux$reducer = _params$redux.reducers,
      reducers = _params$redux$reducer === void 0 ? [] : _params$redux$reducer,
      _params$redux$middlew = _params$redux.middlewares,
      middlewares = _params$redux$middlew === void 0 ? [] : _params$redux$middlew,
      _params$redux$enhance = _params$redux.enhancers,
      enhancers = _params$redux$enhance === void 0 ? [] : _params$redux$enhance,
      _params$redux$sagas = _params$redux.sagas,
      sagas = _params$redux$sagas === void 0 ? [] : _params$redux$sagas;

  if (serializedState != null && initialState != null) {
    throw Error("ambiguous initial state: both initialState and serializedState are set");
  }

  var actualInitialState;

  if (serializedState != null) {
    actualInitialState = (0, _deserializeInitialState["default"])(viewModels, serializedState);
  } else {
    actualInitialState = initialState;
  }

  var combinedReducers = (0, _redux.combineReducers)((0, _extends2["default"])({}, reducers, {
    viewModels: _viewModelReducer.reducer,
    readModels: _readModelReducer.reducer
  }));
  var resolveMiddleware = (0, _createResolveMiddleware["default"])();

  var appliedMiddlewares = _redux.applyMiddleware.apply(void 0, [resolveMiddleware].concat(middlewares));

  var composedEnhancers = _redux.compose.apply(void 0, [appliedMiddlewares].concat(enhancers));

  var store = (0, _redux.createStore)(combinedReducers, actualInitialState, composedEnhancers);
  resolveMiddleware.run(isClient, {
    store: store,
    resolveContext: resolveContext,
    customSagas: sagas,
    sessionId: sessionId
  });
  return store;
};

exports.createResolveStore = createResolveStore;
//# sourceMappingURL=create-resolve-store.js.map