"use strict";

exports.__esModule = true;
exports.isOptions = isOptions;
exports.isActionCreators = isActionCreators;
exports.arrayOfString = exports.leadingSlash = exports.nonEmptyString = exports.assertString = exports.isNonString = exports.isString = exports.isLeadingSlash = exports.isAbsoluteUrl = exports.generateQueryId = exports.isDependencies = void 0;

var _uuid = require("uuid");

var regExpAbsoluteUrl = /:\/\//i;
var regExpLeadingSlash = /^\//i;

function isOptions(x) {
  return x != null && Object(x) === x && x.success == null;
}

function isActionCreators(creators, x) {
  return x && typeof x === 'object' && creators.reduce(function (found, creator) {
    return found || typeof x[creator] === 'function';
  }, false);
}

var isDependencies = function isDependencies(x) {
  return x && x instanceof Array;
};

exports.isDependencies = isDependencies;

var generateQueryId = function generateQueryId(name, resolver) {
  return name + "-" + resolver + "-" + (0, _uuid.v4)();
};

exports.generateQueryId = generateQueryId;

var isAbsoluteUrl = function isAbsoluteUrl(value) {
  return regExpAbsoluteUrl.test(value);
};

exports.isAbsoluteUrl = isAbsoluteUrl;

var isLeadingSlash = function isLeadingSlash(value) {
  return regExpLeadingSlash.test(value);
};

exports.isLeadingSlash = isLeadingSlash;

var isString = function isString(value) {
  return value != null && value.constructor === String;
};

exports.isString = isString;

var isNonString = function isNonString(value) {
  return !isString(value);
};

exports.isNonString = isNonString;

var assertString = function assertString(value, name) {
  if (!isString(value)) {
    // eslint-disable-next-line
    console.error(value);
    throw new Error(name + " must be a string");
  }
};

exports.assertString = assertString;

var nonEmptyString = function nonEmptyString(value, name) {
  assertString(value, name);

  if (value === '') {
    // eslint-disable-next-line
    console.error(value);
    throw new Error(name + " must be a non-empty string");
  }
};

exports.nonEmptyString = nonEmptyString;

var leadingSlash = function leadingSlash(value, name) {
  if (!isLeadingSlash(value)) {
    // eslint-disable-next-line
    console.error(value);
    throw new Error(name + " must have leading \"/\"");
  }
};

exports.leadingSlash = leadingSlash;

var arrayOfString = function arrayOfString(value, name) {
  if (!Array.isArray(value) || value.find(isNonString)) {
    // eslint-disable-next-line
    console.error(value);
    throw new Error(name + " must be an Array<String>");
  }
};

exports.arrayOfString = arrayOfString;
//# sourceMappingURL=helpers.js.map