"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = _interopRequireDefault(require("react"));

var _reactRedux = require("react-redux");

var _redux = require("redux");

var _hoistNonReactStatics = _interopRequireDefault(require("hoist-non-react-statics"));

var _actions = require("./actions");

var _getHash = _interopRequireDefault(require("../internal/get-hash"));

var _connectResolveAdvanced = _interopRequireDefault(require("../internal/connect-resolve-advanced"));

var _types = require("../types");

var _readModelReducer = require("./read-model-reducer");

var connectReadModel = function connectReadModel(mapStateToOptions) {
  return function (Component) {
    var ReadModelContainer = /*#__PURE__*/function (_React$PureComponent) {
      (0, _inheritsLoose2["default"])(ReadModelContainer, _React$PureComponent);

      function ReadModelContainer() {
        return _React$PureComponent.apply(this, arguments) || this;
      }

      var _proto = ReadModelContainer.prototype;

      _proto.componentDidMount = function componentDidMount() {
        var _this$props$connector = this.props.connectorOptions,
            readModelName = _this$props$connector.readModelName,
            resolverName = _this$props$connector.resolverName,
            resolverArgs = _this$props$connector.resolverArgs;
        this.props.connectReadModel({
          name: readModelName,
          resolver: resolverName,
          args: resolverArgs
        });
      };

      _proto.componentWillUnmount = function componentWillUnmount() {
        var _this$props$connector2 = this.props.connectorOptions,
            readModelName = _this$props$connector2.readModelName,
            resolverName = _this$props$connector2.resolverName,
            resolverArgs = _this$props$connector2.resolverArgs;
        this.props.disconnectReadModel({
          name: readModelName,
          resolver: resolverName,
          args: resolverArgs
        });
      };

      _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
        var connectorOptions = this.props.connectorOptions;
        var prevConnectorOptions = prevProps.connectorOptions;

        if (connectorOptions && prevConnectorOptions && (prevConnectorOptions.readModelName !== connectorOptions.readModelName || prevConnectorOptions.resolverName !== connectorOptions.resolverName || prevConnectorOptions.resolverArgs !== connectorOptions.resolverArgs) && (prevConnectorOptions.readModelName !== connectorOptions.readModelName || prevConnectorOptions.resolverName !== connectorOptions.resolverName || (0, _getHash["default"])(prevConnectorOptions.resolverArgs) !== (0, _getHash["default"])(connectorOptions.resolverArgs))) {
          this.props.disconnectReadModel({
            name: prevConnectorOptions.readModelName,
            resolver: prevConnectorOptions.resolverName,
            args: prevConnectorOptions.resolverArgs
          });
          this.props.connectReadModel({
            name: connectorOptions.readModelName,
            resolver: connectorOptions.resolverName,
            args: connectorOptions.resolverArgs
          });
        }
      };

      _proto.render = function render() {
        var _this$props = this.props,
            ownProps = _this$props.ownProps,
            isLoading = _this$props.isLoading,
            data = _this$props.data;
        return /*#__PURE__*/_react["default"].createElement(Component, (0, _extends2["default"])({}, ownProps, {
          isLoading: isLoading,
          data: data
        }));
      };

      return ReadModelContainer;
    }(_react["default"].PureComponent);

    var mapStateToConnectorProps = function mapStateToConnectorProps(state, ownProps) {
      var connectorOptions = mapStateToOptions(state, ownProps);
      var entry = (0, _readModelReducer.getEntry)(state.readModels, {
        query: {
          name: connectorOptions.readModelName,
          resolver: connectorOptions.resolverName,
          args: connectorOptions.resolverArgs
        }
      });
      var data = entry && entry.status === _types.ResultStatus.Ready ? entry.data : null;
      var error = entry && entry.status === _types.ResultStatus.Failed ? entry.error : null;
      return {
        ownProps: ownProps,
        connectorOptions: connectorOptions,
        isLoading: entry && entry.status === _types.ResultStatus.Requested,
        isFailure: entry && entry.status === _types.ResultStatus.Failed,
        data: data,
        error: error
      };
    };

    var mapDispatchToConnectorProps = function mapDispatchToConnectorProps(dispatch) {
      return (0, _redux.bindActionCreators)({
        connectReadModel: _actions.connectReadModel,
        disconnectReadModel: _actions.disconnectReadModel
      }, dispatch);
    };

    var ReadModelConnector = (0, _reactRedux.connect)(mapStateToConnectorProps, mapDispatchToConnectorProps)(ReadModelContainer);
    ReadModelConnector.mapStateToOptions = mapStateToOptions;
    (0, _hoistNonReactStatics["default"])(ReadModelConnector, ReadModelContainer);
    return (0, _connectResolveAdvanced["default"])(ReadModelConnector);
  };
};

var _default = connectReadModel;
exports["default"] = _default;
//# sourceMappingURL=connect-read-model.js.map