"use strict";

exports.__esModule = true;
exports.useReduxReadModel = useReduxReadModel;

var _react = require("react");

var _reactRedux = require("react-redux");

var _core = require("@resolve-js/core");

var _reactHooks = require("@resolve-js/react-hooks");

var _actions = require("./actions");

var _helpers = require("../helpers");

var _readModelReducer = require("./read-model-reducer");

var defaultQueryOptions = {
  method: 'GET'
};
var defaultHookOptions = {};
var internalActions = {
  request: _actions.queryReadModelRequest,
  success: _actions.queryReadModelSuccess,
  failure: _actions.queryReadModelFailure
};

function isBuilder(query) {
  return typeof query === 'function';
}

function useReduxReadModel(query, initialState, options, dependencies) {
  var actualOptions = (0, _helpers.isOptions)(options) ? options : defaultHookOptions;
  var actualActionCreators = actualOptions.actions || internalActions;

  if (isBuilder(query) && !actualOptions.selectorId && actualActionCreators === internalActions) {
    throw Error("Query builder function should be used with selector id or custom redux actions");
  }

  var actualDependencies = (0, _core.firstOfType)(_helpers.isDependencies, options, dependencies);
  var _request = actualActionCreators.request,
      success = actualActionCreators.success,
      failure = actualActionCreators.failure;
  var selectorId = actualOptions.selectorId;

  var callback = function callback(error, result, executedQuery) {
    if (error || result == null) {
      if (typeof failure === 'function') {
        if (error) {
          dispatch(failure(executedQuery, error, selectorId));
        } else {
          dispatch(failure(executedQuery, new Error("null response"), selectorId));
        }
      }
    } else {
      if (typeof success === 'function') {
        dispatch(success(executedQuery, result, selectorId));
      }
    }
  };

  var dispatch = (0, _reactRedux.useDispatch)();
  var executor = actualDependencies ? (0, _reactHooks.useQueryBuilder)(function (query) {
    return query;
  }, actualOptions.queryOptions || defaultQueryOptions, callback, actualDependencies) : (0, _reactHooks.useQueryBuilder)(function (query) {
    return query;
  }, actualOptions.queryOptions || defaultQueryOptions, callback);
  var initialStateDispatched = (0, _react.useRef)(false);

  if (!initialStateDispatched.current) {
    if (selectorId) {
      dispatch((0, _actions.initReadModel)(initialState, undefined, selectorId));
    } else if (!isBuilder(query)) {
      dispatch((0, _actions.initReadModel)(initialState, query, undefined));
    }

    initialStateDispatched.current = true;
  }

  return (0, _react.useMemo)(function () {
    return {
      request: function request() {
        var dispatchRequest = function dispatchRequest(query) {
          if (typeof _request === 'function') {
            dispatch(_request(query, initialState, selectorId));
          }
        };

        var plainQuery = isBuilder(query) ? query.apply(void 0, arguments) : query;
        dispatchRequest(plainQuery);
        executor(plainQuery);
      },
      selector: function selector(state) {
        return (0, _readModelReducer.getEntry)(state.readModels, selectorId || (!isBuilder(query) ? {
          query: query
        } : _readModelReducer.badSelectorDrain));
      }
    };
  }, [executor, dispatch]);
}
//# sourceMappingURL=use-redux-read-model.js.map