"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = exports.mapStateToConnectorProps = exports.mapDispatchToConnectorProps = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _react = _interopRequireDefault(require("react"));

var _uuid = require("uuid");

var _reactRedux = require("react-redux");

var _redux = require("redux");

var _hoistNonReactStatics = _interopRequireDefault(require("hoist-non-react-statics"));

var actions = _interopRequireWildcard(require("./actions"));

var _getHash = _interopRequireDefault(require("../internal/get-hash"));

var _connectResolveAdvanced = _interopRequireDefault(require("../internal/connect-resolve-advanced"));

var _viewModelReducer = require("./view-model-reducer");

var _types = require("../types");

var mapDispatchToConnectorProps = function mapDispatchToConnectorProps(dispatch) {
  return (0, _redux.bindActionCreators)({
    connectViewModel: actions.connectViewModel,
    disconnectViewModel: actions.disconnectViewModel
  }, dispatch);
};

exports.mapDispatchToConnectorProps = mapDispatchToConnectorProps;

var mapStateToConnectorProps = function mapStateToConnectorProps(mapStateToOptions, state, ownProps) {
  var connectorOptions = mapStateToOptions(state, ownProps);
  var entry = (0, _viewModelReducer.getEntry)(state.viewModels, {
    query: {
      name: connectorOptions.viewModelName,
      aggregateIds: connectorOptions.aggregateIds,
      args: connectorOptions.aggregateArgs
    }
  });
  var data = entry && entry.status === _types.ResultStatus.Ready ? entry.data : null;
  var error = entry && entry.status === _types.ResultStatus.Failed ? entry.error : null;
  return {
    ownProps: ownProps,
    connectorOptions: connectorOptions,
    isLoading: entry && entry.status === _types.ResultStatus.Requested,
    isFailure: entry && entry.status === _types.ResultStatus.Failed,
    data: data,
    error: error
  };
};

exports.mapStateToConnectorProps = mapStateToConnectorProps;

var connectViewModel = function connectViewModel(mapStateToOptions) {
  return function (Component) {
    var selectorId = (0, _uuid.v4)();

    var ViewModelContainer = /*#__PURE__*/function (_React$PureComponent) {
      (0, _inheritsLoose2["default"])(ViewModelContainer, _React$PureComponent);

      function ViewModelContainer() {
        return _React$PureComponent.apply(this, arguments) || this;
      }

      var _proto = ViewModelContainer.prototype;

      _proto.componentDidMount = function componentDidMount() {
        var _this$props$connector = this.props.connectorOptions,
            viewModelName = _this$props$connector.viewModelName,
            aggregateIds = _this$props$connector.aggregateIds,
            aggregateArgs = _this$props$connector.aggregateArgs;
        this.props.connectViewModel({
          name: viewModelName,
          aggregateIds: aggregateIds,
          args: aggregateArgs
        }, selectorId);
      };

      _proto.componentWillUnmount = function componentWillUnmount() {
        var _this$props$connector2 = this.props.connectorOptions,
            viewModelName = _this$props$connector2.viewModelName,
            aggregateIds = _this$props$connector2.aggregateIds,
            aggregateArgs = _this$props$connector2.aggregateArgs;
        this.props.disconnectViewModel({
          name: viewModelName,
          aggregateIds: aggregateIds,
          args: aggregateArgs
        }, selectorId);
      };

      _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
        var connectorOptions = this.props.connectorOptions;
        var prevConnectorOptions = prevProps.connectorOptions;

        if (connectorOptions && prevConnectorOptions && (prevConnectorOptions.viewModelName !== connectorOptions.viewModelName || prevConnectorOptions.aggregateIds !== connectorOptions.aggregateIds || prevConnectorOptions.aggregateArgs !== connectorOptions.aggregateArgs) && (prevConnectorOptions.viewModelName !== connectorOptions.viewModelName || (0, _getHash["default"])(prevConnectorOptions.aggregateIds) !== (0, _getHash["default"])(connectorOptions.aggregateIds) || (0, _getHash["default"])(prevConnectorOptions.aggregateArgs, 'empty') !== (0, _getHash["default"])(connectorOptions.aggregateArgs, 'empty'))) {
          this.props.disconnectViewModel(prevConnectorOptions.viewModelName, prevConnectorOptions.aggregateIds, prevConnectorOptions.aggregateArgs);
          this.props.connectViewModel(connectorOptions.viewModelName, connectorOptions.aggregateIds, connectorOptions.aggregateArgs);
        }
      };

      _proto.render = function render() {
        var _this$props = this.props,
            ownProps = _this$props.ownProps,
            isLoading = _this$props.isLoading,
            data = _this$props.data;
        return /*#__PURE__*/_react["default"].createElement(Component, (0, _extends2["default"])({}, ownProps, {
          isLoading: isLoading,
          data: data
        }));
      };

      return ViewModelContainer;
    }(_react["default"].PureComponent);

    var ViewModelConnector = (0, _reactRedux.connect)(mapStateToConnectorProps.bind(null, mapStateToOptions), mapDispatchToConnectorProps)(ViewModelContainer);
    ViewModelConnector.mapStateToOptions = mapStateToOptions;
    (0, _hoistNonReactStatics["default"])(ViewModelConnector, ViewModelContainer);
    return (0, _connectResolveAdvanced["default"])(ViewModelConnector);
  };
};

var _default = connectViewModel;
exports["default"] = _default;
//# sourceMappingURL=connect-view-model.js.map