"use strict";

exports.__esModule = true;
exports.useReduxViewModel = useReduxViewModel;

var _actions = require("./actions");

var _helpers = require("../helpers");

var _reactRedux = require("react-redux");

var _reactHooks = require("@resolve-js/react-hooks");

var _react = require("react");

var _viewModelReducer = require("./view-model-reducer");

var defaultQueryOptions = {
  method: 'GET'
};
var defaultHookOptions = {};
var internalActions = {
  stateUpdate: _actions.viewModelStateUpdate,
  eventReceived: _actions.viewModelEventReceived
};

function useReduxViewModel(query, options) {
  var actualOptions = (0, _helpers.isOptions)(options) ? options : defaultHookOptions;
  var actualActionCreators = actualOptions.actions || internalActions;
  var stateUpdate = actualActionCreators.stateUpdate,
      eventReceived = actualActionCreators.eventReceived;
  var selectorId = actualOptions.selectorId;
  var name = query.name,
      aggregateIds = query.aggregateIds,
      args = query.args;
  var dispatch = (0, _reactRedux.useDispatch)();
  var stateChangeCallback = (0, _react.useCallback)(function (state, initial) {
    if (typeof stateUpdate === 'function' && !initial) {
      dispatch(stateUpdate(query, state, initial, selectorId));
    }
  }, []);
  var eventReceivedCallback = (0, _react.useCallback)(function (event) {
    if (typeof eventReceived === 'function') {
      dispatch(eventReceived(query, event, selectorId));
    }
  }, []);

  var _useViewModel = (0, _reactHooks.useViewModel)(name, aggregateIds, args, stateChangeCallback, eventReceivedCallback, actualOptions.queryOptions || defaultQueryOptions),
      connect = _useViewModel.connect,
      dispose = _useViewModel.dispose,
      initialState = _useViewModel.initialState;

  var initialStateDispatched = (0, _react.useRef)(false);

  if (!initialStateDispatched.current) {
    if (typeof stateUpdate === 'function') {
      dispatch(stateUpdate(query, initialState, true, selectorId));
    }

    initialStateDispatched.current = true;
  }

  return (0, _react.useMemo)(function () {
    return {
      connect: connect,
      dispose: dispose,
      selector: function selector(state) {
        return (0, _viewModelReducer.getEntry)(state.viewModels, selectorId || {
          query: query
        });
      }
    };
  }, [connect, dispose]);
}
//# sourceMappingURL=use-redux-view-model.js.map