import { AnyAction } from 'redux';
import { QueryOptions, QueryResult, ReadModelQuery } from '@resolve-js/client';
import { QueryBuilder } from '@resolve-js/react-hooks';
import { QueryReadModelFailureAction, QueryReadModelRequestAction, QueryReadModelSuccessAction } from './actions';
import { ReduxState } from '../types';
declare type HookData<TArgs extends any[]> = {
    request: (...args: TArgs) => void;
    selector: (state: ReduxState) => any;
};
declare type ReadModelReduxActionsCreators<TQuery extends ReadModelQuery> = {
    request?: (query: TQuery, initialState: any, selectorId?: string) => QueryReadModelRequestAction | AnyAction;
    success?: (query: TQuery, result: QueryResult, selectorId?: string) => QueryReadModelSuccessAction | AnyAction;
    failure?: (query: TQuery, error: Error, selectorId?: string) => QueryReadModelFailureAction | AnyAction;
};
export declare type ReduxReadModelHookOptions<TQuery extends ReadModelQuery> = {
    actions?: ReadModelReduxActionsCreators<TQuery>;
    queryOptions?: QueryOptions;
    selectorId?: string;
};
declare function useReduxReadModel<TQuery extends ReadModelQuery>(query: TQuery, initialState: any): HookData<void[]>;
declare function useReduxReadModel<TQuery extends ReadModelQuery>(query: TQuery, initialState: any, options: ReduxReadModelHookOptions<TQuery>): HookData<void[]>;
declare function useReduxReadModel<TQuery extends ReadModelQuery>(query: TQuery, initialState: any, dependencies: any[]): HookData<void[]>;
declare function useReduxReadModel<TQuery extends ReadModelQuery>(query: TQuery, initialState: any, options: ReduxReadModelHookOptions<TQuery>, dependencies: any[]): HookData<void[]>;
declare function useReduxReadModel<TArgs extends any[], TQuery extends ReadModelQuery>(builder: QueryBuilder<TArgs, TQuery>, initialState: any): HookData<TArgs>;
declare function useReduxReadModel<TArgs extends any[], TQuery extends ReadModelQuery>(builder: QueryBuilder<TArgs, TQuery>, initialState: any, options: ReduxReadModelHookOptions<TQuery>): HookData<TArgs>;
declare function useReduxReadModel<TArgs extends any[], TQuery extends ReadModelQuery>(builder: QueryBuilder<TArgs, TQuery>, initialState: any, dependencies: any[]): HookData<TArgs>;
declare function useReduxReadModel<TArgs extends any[], TQuery extends ReadModelQuery>(builder: QueryBuilder<TArgs, TQuery>, initialState: any, options: ReduxReadModelHookOptions<TQuery>, dependencies: any[]): HookData<TArgs>;
export { useReduxReadModel };
